(***********************************************************************)
(*                                                                     *)
(*                              Ref-image                              *)
(*                                                                     *)
(*                  Image Segmentation by Refinement                   *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2009-2013 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: image.ml,v 1.55 2013-12-02 15:28:38 fclement Exp $ *)

module Nat = Unatural;;

module Set = Umatrix_nonempty_set;;
module Mapping = Umatrix_graph;;
module Structural_mapping = Umatrix_structural_mapping;;

open Segmentation_types;;

(*let point_digest =
  Utype_digest.couple_digest Utype_digest.int_digest Utype_digest.int_digest
;;
let gimage_digest = Mapping.extensional_mapping_digest point_digest
and cimage_digest = Mapping.structural_mapping_digest point_digest
;;*)

let same_gimage gim1 gim2 = Mapping.same gim1 gim2;;

let same_cimage (j1, pim1) (j2, pim2) =
  j1 = j2 && Structural_mapping.same pim1 pim2
;;

let last_zone_number = Structural_mapping.last_block_number;;

(* Converters. *)

(*
let image_combine (m1, m2, m3) =
  let (h, w) = Umatrix.size m3 in
  Umatrix.init h w
    (fun i j -> Umatrix.get m1 i j + Umatrix.get m2 i j + Umatrix.get m3 i j)
;;
*)

let scalar_to_channels scalar_to_int =
  let sti cf = Upervasives.compose cf scalar_to_int in
  let scalar_to_red cf s = Colors.color_of_rgb (sti cf s) 0 0
  and scalar_to_green cf s = Colors.color_of_rgb 0 (sti cf s) 0
  and scalar_to_blue cf s = Colors.color_of_rgb 0 0 (sti cf s) in
  (scalar_to_red, scalar_to_green, scalar_to_blue)
;;

let gimage_of_image of_color im = Mapping.make (Umatrix.map of_color im);;

let set_pixmap_of_full_gimage set_pixel to_color
    { Mapping.domain = dom; images = images; } =
  let f =
    match images with
    | Mapping.Constant y ->
        (fun _idx _uidx (i, j) ->
           let (i, j) = (Nat.to_int i, Nat.to_int j) in
           let c = to_color y in
           set_pixel c i j)
    | Mapping.Images ims ->
        (fun idx _uidx (i, j) ->
           let (i, j) = (Nat.to_int i, Nat.to_int j) in
           let c = to_color ims.(Uindex_index.to_int idx) in
           set_pixel c i j) in
  Set.full_iter f dom;
;;

let image_of_full_gimage to_color gim =
  let w = Configuration.get_image_width ()
  and h = Configuration.get_image_height () in
  let im = Umatrix.make h w Graphics.transp in
  set_pixmap_of_full_gimage (fun c i j -> Umatrix.set im i j c) to_color gim;
  im
;;

let constant_zone mean gdata_sub cost_sub gdata =
  let dom = gdata_sub.Mapping.domain in
  let param = mean gdata_sub in
  let gim_sub = Mapping.constant dom param in
  let ct = cost_sub gdata gim_sub in
  let zc = { zc_param = param; zc_cost = ct; } in
  Mapping.constant dom zc
;;

let cimage_of_gimage cut mean cost_sub cost gdata =
  let map = constant_zone mean gdata cost_sub gdata in
  let pim = Structural_mapping.of_graph cut map in
  let ct = cost pim in
  (ct, pim)
;;

let param zim = Mapping.map_images (fun zc -> zc.zc_param) zim;;

let gimage_of_cimage (_j, pim) =
  let gim = Structural_mapping.to_graph pim in
  param gim
;;

let sub_gimage f gim map =
  let dom = map.Mapping.domain in
  let ff =
    match map.Mapping.images with
    | Mapping.Constant y ->
        (fun _idx uidx ->
          f (Mapping.image gim (Set.full_index_of_uindex uidx)) y)
    | Mapping.Images _ ->
        (fun idx uidx ->
          f
            (Mapping.image gim (Set.full_index_of_uindex uidx))
            (Mapping.image map idx)) in
  Mapping.from_fun dom ff
;;

(* Image iterators. *)

let gimage_map f = Mapping.map_images f;;

let pimage_iter = Structural_mapping.iter;;

let pimage_fold_left = Structural_mapping.fold_left;;

let pimage_iter_to_do = Structural_mapping.iter_to_do;;

let pimage_iter_value = Structural_mapping.iter_value;;
let pimage_fold_left_value = Structural_mapping.fold_left_value;;

(* Domain operations. *)

let bounds_of_domain dom =
  let box { ll = (imin, jmin); ur = (imax, jmax); } idx _ =
    let (i, j) = Set.element dom idx in
    { ll = (min i imin, min j jmin); ur = (max i imax, max j jmax); } in
  let (idx, _) = Set.choice dom in
  let pt = Set.element dom idx in
  Set.fold_left box { ll = pt; ur = pt; } dom
;;
