(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2004-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* Beginning of ocamlprint_xmlc.bin generated code *)

let print_xml_purpose ppf = function
  | Udebug.User -> Format.fprintf ppf "%s" "<User/>"
  | Udebug.Library -> Format.fprintf ppf "%s" "<Library/>"

and print_xml_software_name ppf = function
  | s -> Lib_print_xml.print_xml_quoted_string ppf s

and print_xml_prefix ppf = function
  | s -> Lib_print_xml.print_xml_quoted_string ppf s
;;

let rec print_xml_short_key_prefix ppf = function
  | Udebug.Automatic -> Format.fprintf ppf "%s" "<Automatic/>"
  | Udebug.Short p ->
    Format.fprintf ppf "@[<1>%s@," "<Short>"; print_xml_prefix ppf p;
    Format.fprintf ppf "%,</Short>"; Format.fprintf ppf "%,@]"

and print_xml_key_prefixes ppf = function
  | { Udebug.long = p; Udebug.short = s; } ->
    Format.fprintf ppf "%,@[<1>{@,"; print_xml_prefix ppf p;
    Format.fprintf ppf "%,;"; print_xml_short_key_prefix ppf s;
    Format.fprintf ppf "%,;"; Format.fprintf ppf "%,@,}@]"
;;

let print_xml_printing_facilities px_a ppf = function
  | {
      Udebug.report = f_u_m_b;
      Udebug.report_action = f_f_u_u_m_b;
      Udebug.debug = f_u_f_f_u_m_b;
      Udebug.debug_action = f_u_f_f_f_u_u_m_b;
      Udebug.fatal_error = f_u_f_f_u_m_f_i_a;
    } ->
    Format.fprintf ppf "%,@[<1>{@,";
    Lib_print_xml.print_xml_fun Upervasives_print_xml.print_xml_message
     Lib_print_xml.print_xml_bool ppf f_u_m_b;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun
     (Lib_print_xml.print_xml_fun Lib_print_xml.print_xml_unit
       Upervasives_print_xml.print_xml_message
     ) Lib_print_xml.print_xml_bool ppf f_f_u_u_m_b;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun Upervasives_print_xml.print_xml_function_name
     (Lib_print_xml.print_xml_fun Upervasives_print_xml.print_xml_message
       Lib_print_xml.print_xml_bool
     ) ppf f_u_f_f_u_m_b;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun Upervasives_print_xml.print_xml_function_name
     (Lib_print_xml.print_xml_fun
       (Lib_print_xml.print_xml_fun Lib_print_xml.print_xml_unit
         Upervasives_print_xml.print_xml_message
       ) Lib_print_xml.print_xml_bool
     ) ppf f_u_f_f_f_u_u_m_b;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun Upervasives_print_xml.print_xml_function_name
     (Lib_print_xml.print_xml_fun Upervasives_print_xml.print_xml_message
       (Lib_print_xml.print_xml_fun Lib_print_xml.print_xml_quoted_int px_a)
     ) ppf f_u_f_f_u_m_f_i_a;
    Format.fprintf ppf "%,;"; Format.fprintf ppf "%,@,}@]"
;;

let rec print_xml_tag ppf = function
  | s -> Lib_print_xml.print_xml_quoted_string ppf s

and print_xml_dynamic_tag px_a ppf = function
  | f_a_t -> Lib_print_xml.print_xml_fun px_a print_xml_tag ppf f_a_t
;;

let print_xml_dynamic_printing_facilities px_a px_b ppf = function
  | {
      Udebug.dyn_report = f_a_f_u_m_b;
      Udebug.dyn_report_action = f_a_f_f_u_u_m_b;
      Udebug.dyn_debug = f_a_f_u_f_f_u_m_b;
      Udebug.dyn_debug_action = f_a_f_u_f_f_f_u_u_m_b;
      Udebug.dyn_fatal_error = f_a_f_u_f_f_u_m_f_i_b;
    } ->
    Format.fprintf ppf "%,@[<1>{@,";
    Lib_print_xml.print_xml_fun px_a
     (Lib_print_xml.print_xml_fun Upervasives_print_xml.print_xml_message
       Lib_print_xml.print_xml_bool
     ) ppf f_a_f_u_m_b;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun px_a
     (Lib_print_xml.print_xml_fun
       (Lib_print_xml.print_xml_fun Lib_print_xml.print_xml_unit
         Upervasives_print_xml.print_xml_message
       ) Lib_print_xml.print_xml_bool
     ) ppf f_a_f_f_u_u_m_b;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun px_a
     (Lib_print_xml.print_xml_fun
       Upervasives_print_xml.print_xml_function_name
       (Lib_print_xml.print_xml_fun Upervasives_print_xml.print_xml_message
         Lib_print_xml.print_xml_bool
       )
     ) ppf f_a_f_u_f_f_u_m_b;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun px_a
     (Lib_print_xml.print_xml_fun
       Upervasives_print_xml.print_xml_function_name
       (Lib_print_xml.print_xml_fun
         (Lib_print_xml.print_xml_fun Lib_print_xml.print_xml_unit
           Upervasives_print_xml.print_xml_message
         ) Lib_print_xml.print_xml_bool
       )
     ) ppf f_a_f_u_f_f_f_u_u_m_b;
    Format.fprintf ppf "%,;";
    Lib_print_xml.print_xml_fun px_a
     (Lib_print_xml.print_xml_fun
       Upervasives_print_xml.print_xml_function_name
       (Lib_print_xml.print_xml_fun Upervasives_print_xml.print_xml_message
         (Lib_print_xml.print_xml_fun Lib_print_xml.print_xml_quoted_int px_b
         )
       )
     ) ppf f_a_f_u_f_f_u_m_f_i_b;
    Format.fprintf ppf "%,;"; Format.fprintf ppf "%,@,}@]"
;;

(* End of ocamlprint_xmlc.bin generated code *)
