(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2004-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: uchar.ml,v 1.7 2014/01/10 15:28:04 fclement Exp $ *)

exception Unextended_char of char;;
exception Digram of char * char;;

let iso_latin1_to_us_ascii = function
| '\000' .. '\127' as c -> c
| '\128' .. '\191' | '\215' | '\247' as c -> raise (Unextended_char c)
| '\192' .. '\197' -> 'A'               (* Latin diacritic A's. *)
| '\198' -> raise (Digram ('A', 'E'))   (* Latin A-E ligature. *)
| '\199' -> 'C'                         (* Latin C-cedilla. *)
| '\200' .. '\203' -> 'E'               (* Latin diacritic E's. *)
| '\204' .. '\207' -> 'I'               (* Latin diacritic I's. *)
| '\208' -> 'D'                         (* Icelandic Eth. *)
| '\209' -> 'N'                         (* Latin Enye. *)
| '\210' .. '\214' | '\216' -> 'O'      (* Latin diacritic O's. *)
| '\217' .. '\220' -> 'U'               (* Latin diacritic U's. *)
| '\221' -> 'Y'                         (* Latin acute Y. *)
| '\222' -> raise (Digram ('T', 'h'))   (* Icelandic Thorn. *)
| '\223' -> raise (Digram ('s', 's'))   (* German eszett. *)
| '\224' .. '\229' -> 'a'               (* Latin diacritic a's. *)
| '\230' -> raise (Digram ('a', 'e'))   (* Latin a-e ligature. *)
| '\231' -> 'c'                         (* Latin c-cedilla. *)
| '\232' .. '\235' -> 'e'               (* Latin diacritic e's. *)
| '\236' .. '\239' -> 'i'               (* Latin diacritic i's. *)
| '\240' -> 'd'                         (* Icelandic eth. *)
| '\241' -> 'n'                         (* Latin enye. *)
| '\242' .. '\246' | '\248' -> 'o'      (* Latin diacritic o's. *)
| '\249' .. '\252' -> 'u'               (* Latin diacritic u's. *)
| '\253' | '\255' -> 'y'                (* Latin diacritic y's. *)
| '\254' -> raise (Digram ('t', 'h'))   (* Icelandic thorn. *)
;;

let is_us_ascii = function
| '\000' .. '\127' -> true
| _ -> false
;;

let is_alphabetic = function
| 'A' .. 'Z' | 'a' .. 'z'
| '\192' .. '\214' | '\216' .. '\246' | '\248' .. '\255' -> true
| _ -> false
;;

let is_numeric = function
| '0' .. '9' -> true
| _ -> false
;;

let is_alphanumeric c =
  is_alphabetic c || is_numeric c
;;

let is_space = function
| ' ' | '\012' | '\n' | '\r' | '\t' -> true
| _ -> false
;;

let is_punctuation = function
| '!' | '\"' | '\'' | '(' | ')' | ',' | '-' | '.' | ':' | ';' | '?' | '`'
| '\160' | '\161' | '\171' | '\187' | '\191' -> true
| _ -> false
;;

let is_mathematical = function
| '%' | '(' | ')' | '*' | '+' | '-' | '/' | '<'
| '=' | '>' | '[' | '\\' | ']' | '{' | '|' | '}'
| '\177' | '\215' | '\247' -> true
| _ -> false
;;
