(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2004-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: upph_id_card.mli,v 1.10 2014/01/10 15:28:04 fclement Exp $ *)

(** {3 Handling the user part of the id card of a Pph project} *)

type pph_id_card = {
  project_name : string;
  project_banner_title : string;
  project_outline : string;
  project_release_date : string;
  project_copyright_handlers : string;
  project_authors : string;
  project_http_url : string;
  project_ftp_url : string;
  project_release_ident : string;
  project_distribution_ident : string;
  project_version : string;
  project_version_full_info : string;
  project_release_name : string;
  project_distribution_name : string;
}
;;

type t = pph_id_card;;

val make_print_short_version : t -> unit -> unit;;
 (** Given a [pph_id_card] record, returns a function that prints the short
   form of the version information of the Pph project on [stderr].
   The intended use of this function is to compute a function to handle the
   [-v] command line option parsed with the [Arg] standard library module. *)

val make_print_long_version : t -> unit -> unit;;
 (** Same as above for the long form of the version information of the Pph
   project.
   The intended use of this function is to compute a function to handle the
   [--version] command line option parsed with the [Arg] standard library
   module. *)

val add_user_version_options : t -> unit;;
 (** Compute the version information for [pph_id_card] and add relevant
   [-v] and [--version] command options using the module [Ucommand_options]. *)

val add_library_version_options : t -> unit;;
 (** Compute the version information for [pph_id_card] and add relevant
   [-*v] and [--*-version] command options using the module [Ucommand_option]
   (where the [*] stand for some distinctive string computed from the name of
   the library). *)
